@@ -2,9 +2,7 @@ package config
 
 import (
 	"context"
-	"encoding/json"
 	"fmt"
-	"github.com/infracost/infracost/internal/logging"
 	"io"
 	"os"
 	"runtime"
@@ -12,6 +10,9 @@ import (
 	"sync"
 	"time"
 
+	"github.com/infracost/infracost/internal/logging"
+	"github.com/infracost/infracost/internal/vcs"
+
 	"github.com/google/uuid"
 	log "github.com/sirupsen/logrus"
 
@@ -24,6 +25,8 @@ type RunContext struct {
 	uuid        uuid.UUID
 	Config      *Config
 	State       *State
+	VCSMetadata vcs.Metadata
+	CMD         string
 	contextVals map[string]interface{}
 	mu          *sync.RWMutex
 	StartTime   int64
@@ -249,6 +252,7 @@ var ciMap = ciEnvMap{
 		"TDDIUM":               "tddium",
 		"GREENHOUSE":           "greenhouse",
 		"CIRRUS_CI":            "cirrusci",
+		"TS_ENV":               "terraspace",
 	},
 	prefixes: map[string]string{
 		"ATLANTIS_":  "atlantis",
@@ -256,6 +260,8 @@ var ciMap = ciEnvMap{
 		"CONCOURSE_": "concourse",
 		"SPACELIFT_": "spacelift",
 		"HARNESS_":   "harness",
+		"TERRATEAM_": "terrateam",
+		"KEPTN_":     "keptn",
 	},
 }
 
@@ -280,48 +286,3 @@ func ciPlatform() string {
 
 	return ""
 }
-
-func ciVCSRepo() string {
-	if IsEnvPresent("GITHUB_REPOSITORY") {
-		serverURL := os.Getenv("GITHUB_SERVER_URL")
-		if serverURL == "" {
-			serverURL = "https://github.com"
-		}
-		return fmt.Sprintf("%s/%s", serverURL, os.Getenv("GITHUB_REPOSITORY"))
-	} else if IsEnvPresent("CI_PROJECT_URL") {
-		return os.Getenv("CI_PROJECT_URL")
-	} else if IsEnvPresent("BUILD_REPOSITORY_URI") {
-		return os.Getenv("BUILD_REPOSITORY_URI")
-	} else if IsEnvPresent("BITBUCKET_GIT_HTTP_ORIGIN") {
-		return os.Getenv("BITBUCKET_GIT_HTTP_ORIGIN")
-	} else if IsEnvPresent("CIRCLE_REPOSITORY_URL") {
-		return os.Getenv("CIRCLE_REPOSITORY_URL")
-	}
-
-	return ""
-}
-
-func ciVCSPullRequestURL() string {
-	if IsEnvPresent("GITHUB_EVENT_PATH") && os.Getenv("GITHUB_EVENT_NAME") == "pull_request" {
-		b, err := os.ReadFile(os.Getenv("GITHUB_EVENT_PATH"))
-		if err != nil {
-			log.Debugf("Error reading GITHUB_EVENT_PATH file: %v", err)
-		}
-
-		var event struct {
-			PullRequest struct {
-				HTMLURL string `json:"html_url"`
-			} `json:"pull_request"`
-		}
-
-		err = json.Unmarshal(b, &event)
-		if err != nil {
-			log.Debugf("Error reading GITHUB_EVENT_PATH JSON: %v", err)
-		}
-
-		return event.PullRequest.HTMLURL
-	} else if IsEnvPresent("CI_PROJECT_URL") && IsEnvPresent("CI_MERGE_REQUEST_IID") {
-		return fmt.Sprintf("%s/merge_requests/%s", os.Getenv("CI_PROJECT_URL"), os.Getenv("CI_MERGE_REQUEST_IID"))
-	}
-	return ""
-}
