@@ -618,7 +618,11 @@ func addressResourcePart(addr string) string {
 		return strings.Join(p[len(p)-3:], ".")
 	}
 
-	return strings.Join(p[len(p)-2:], ".")
+	if len(p) >= 2 {
+		return strings.Join(p[len(p)-2:], ".")
+	}
+
+	return ""
 }
 
 // addressModulePart parses a resource addr and returns module prefix.
@@ -630,7 +634,7 @@ func addressModulePart(addr string) string {
 
 	if len(ap) >= 3 && ap[len(ap)-3] == "data" {
 		mp = ap[:len(ap)-3]
-	} else {
+	} else if len(ap) >= 2 {
 		mp = ap[:len(ap)-2]
 	}
 
@@ -685,6 +689,10 @@ func removeAddressArrayPart(addr string) string {
 	r := regexp.MustCompile(`([^\[]+)`)
 	m := r.FindStringSubmatch(addressResourcePart(addr))
 
+	if len(m) == 0 {
+		return ""
+	}
+
 	return m[1]
 }
 
