@@ -1,34 +1,13 @@
 package schema
 
 import (
-	"encoding/json"
 	"fmt"
 	"strings"
 
+	jsoniter "github.com/json-iterator/go"
 	"github.com/tidwall/gjson"
 )
 
-type UsageVariableType int
-
-const (
-	Int64 UsageVariableType = iota
-	String
-	Float64
-	StringArray
-)
-
-// type UsageDataValidatorFuncType = func(value interface{}) error
-
-type UsageSchemaItem struct {
-	Key          string
-	DefaultValue interface{}
-	ValueType    UsageVariableType
-	// These aren't used yet and I'm not entirely sure how they fit in, but they were part of the discussion about usage schema.
-	// ValidatorFunc UsageDataValidatorFuncType
-	// SubUsageData  *UsageSchemaItem
-	// Description   string
-}
-
 type UsageData struct {
 	Address    string
 	Attributes map[string]gjson.Result
@@ -92,6 +71,22 @@ func (u *UsageData) GetStringArray(key string) *[]string {
 	return nil
 }
 
+// Return true if the key doesn't exist, is null, or is an empty string.
+// Needed because gjson.Exists returns true as long as a key exists, even if it's empty or null.
+func (u *UsageData) IsEmpty(key string) bool {
+	g := u.Get(key)
+	return g.Type == gjson.Null || len(g.Raw) == 0 || g.Raw == "\"\"" || emptyObjectOrArray(g)
+}
+
+func emptyObjectOrArray(g gjson.Result) bool {
+	empty := true
+	g.ForEach(func(key, val gjson.Result) bool {
+		empty = false
+		return false // exit the ForEach after the first value
+	})
+	return empty
+}
+
 func convertArrayKeyToWildcard(key string) string {
 	lastOpenBracket := strings.LastIndex(key, "[")
 	lastCloseBracket := strings.LastIndex(key, "]")
@@ -136,33 +131,21 @@ func NewEmptyUsageMap() map[string]*UsageData {
 
 func ParseAttributes(i interface{}) map[string]gjson.Result {
 	a := make(map[string]gjson.Result)
-	for k, v := range flatten(i) {
-		j, _ := json.Marshal(v)
-		a[k] = gjson.ParseBytes(j)
+
+	switch attrs := i.(type) {
+	case map[string]interface{}:
+		for k, v := range attrs {
+			// we use the jsoniter lib here as the std lib json
+			// cannot handle marshalling map[interface{}]interface{}
+			j, _ := jsoniter.Marshal(v)
+			a[k] = gjson.ParseBytes(j)
+		}
+	case map[interface{}]interface{}:
+		for k, v := range attrs {
+			j, _ := jsoniter.Marshal(v)
+			a[fmt.Sprintf("%s", k)] = gjson.ParseBytes(j)
+		}
 	}
 
 	return a
 }
-
-func flatten(i interface{}) map[string]interface{} {
-	keys := make([]string, 0)
-	result := make(map[string]interface{})
-	flattenHelper(i, keys, result)
-	return result
-}
-
-func flattenHelper(i interface{}, keys []string, result map[string]interface{}) {
-	switch v := i.(type) {
-	case map[string]interface{}:
-		for k, v := range i.(map[string]interface{}) {
-			flattenHelper(v, append(keys, k), result)
-		}
-	case map[interface{}]interface{}:
-		for k, v := range i.(map[interface{}]interface{}) {
-			flattenHelper(v, append(keys, fmt.Sprintf("%v", k)), result)
-		}
-	default:
-		k := strings.Join(keys, ".")
-		result[k] = v
-	}
-}
