@@ -9,6 +9,7 @@ import (
 	"net/url"
 	"os"
 	"regexp"
+	"strconv"
 	"strings"
 	"sync"
 	"time"
@@ -45,23 +46,184 @@ var (
 	startsWithMerge  = regexp.MustCompile(`(?i)^merge`)
 	versionRegxp     = regexp.MustCompile(`^v\d/`)
 
-	repoOverrideURL = strings.TrimSpace(os.Getenv("INFRACOST_VCS_REPOSITORY_URL"))
-	prOverrideURL   = strings.TrimSpace(os.Getenv("INFRACOST_VCS_PULL_REQUEST_URL"))
-	defaultMetadata = buildDefaultMetadata()
+	allowedProviders = map[string]struct{}{
+		"github": {}, "gitlab": {}, "azure_repos": {}, "bitbucket": {},
+	}
 )
 
-func buildDefaultMetadata() Metadata {
+func getEnv(key string) string {
+	return strings.TrimSpace(os.Getenv(key))
+}
+
+func buildEnvProvidedMetadata() Metadata {
+	remote := urlStringToRemote(getEnv("INFRACOST_VCS_REPOSITORY_URL"))
 	m := Metadata{
-		Remote: urlStringToRemote(repoOverrideURL),
+		Remote: remote,
+		Branch: Branch{
+			Name: getEnv("INFRACOST_VCS_BRANCH"),
+		},
+		Commit:      buildDefaultCommit(),
+		PullRequest: buildDefaultPR(),
+		Pipeline:    &Pipeline{ID: getEnv("INFRACOST_VCS_PIPELINE_RUN_ID")},
 	}
 
-	if prOverrideURL != "" {
-		m.PullRequest = &PullRequest{URL: prOverrideURL}
+	if m.PullRequest != nil && m.PullRequest.VCSProvider == "" {
+		m.PullRequest.VCSProvider = vcsProviderFromHost(remote.Host)
 	}
 
 	return m
 }
 
+func mergeEnvProvidedMetadata(m Metadata) Metadata {
+	envMeta := buildEnvProvidedMetadata()
+	if envMeta.Remote.Host != "" {
+		m.Remote = envMeta.Remote
+	}
+
+	m.Branch = Branch{
+		Name: useEnvValueOrParsedString(envMeta.Branch.Name, m.Branch.Name),
+	}
+
+	m.Commit = Commit{
+		SHA:         useEnvValueOrParsedString(envMeta.Commit.SHA, m.Commit.SHA),
+		AuthorName:  useEnvValueOrParsedString(envMeta.Commit.AuthorName, m.Commit.AuthorName),
+		AuthorEmail: useEnvValueOrParsedString(envMeta.Commit.AuthorEmail, m.Commit.AuthorEmail),
+		Time:        useEnvValueOrParsedTime(envMeta.Commit.Time, m.Commit.Time),
+		Message:     useEnvValueOrParsedString(envMeta.Commit.Message, m.Commit.Message),
+	}
+
+	if envMeta.PullRequest != nil {
+		if m.PullRequest == nil {
+			m.PullRequest = envMeta.PullRequest
+		} else {
+			m.PullRequest = &PullRequest{
+				ID:           useEnvValueOrParsedString(envMeta.PullRequest.ID, m.PullRequest.ID),
+				VCSProvider:  useEnvValueOrParsedString(envMeta.PullRequest.VCSProvider, m.PullRequest.VCSProvider),
+				Title:        useEnvValueOrParsedString(envMeta.PullRequest.Title, m.PullRequest.Title),
+				Author:       useEnvValueOrParsedString(envMeta.PullRequest.Author, m.PullRequest.Author),
+				SourceBranch: useEnvValueOrParsedString(envMeta.PullRequest.SourceBranch, m.PullRequest.SourceBranch),
+				BaseBranch:   useEnvValueOrParsedString(envMeta.PullRequest.BaseBranch, m.PullRequest.BaseBranch),
+				URL:          useEnvValueOrParsedString(envMeta.PullRequest.URL, m.PullRequest.URL),
+			}
+		}
+	}
+
+	if m.PullRequest != nil && m.PullRequest.VCSProvider == "" {
+		m.PullRequest.VCSProvider = vcsProviderFromHost(m.Remote.Host)
+	}
+
+	if envMeta.Pipeline.ID != "" {
+		m.Pipeline = &Pipeline{
+			ID: envMeta.Pipeline.ID,
+		}
+	}
+
+	return m
+}
+
+func useEnvValueOrParsedTime(envVal time.Time, parsedVal time.Time) time.Time {
+	if !envVal.IsZero() {
+		return envVal
+	}
+
+	return parsedVal
+}
+
+func useEnvValueOrParsedString(envVal string, parsedVal string) string {
+	if envVal != "" {
+		return envVal
+	}
+
+	return parsedVal
+}
+
+func buildDefaultPR() *PullRequest {
+	if !keysSet(
+		"INFRACOST_VCS_PULL_REQUEST_ID",
+		"INFRACOST_VCS_PROVIDER",
+		"INFRACOST_VCS_PULL_REQUEST_TITLE",
+		"INFRACOST_VCS_PULL_REQUEST_AUTHOR",
+		"INFRACOST_VCS_BRANCH",
+		"INFRACOST_VCS_BASE_BRANCH",
+		"INFRACOST_VCS_PULL_REQUEST_URL",
+	) {
+		return nil
+	}
+
+	provider := strings.ToLower(getEnv("INFRACOST_VCS_PROVIDER"))
+	if _, ok := allowedProviders[provider]; !ok && provider != "" {
+		logging.Logger.Warnf("provided value for INFRACOST_VCS_PROVIDER '%s' is not valid. Setting vcsProvider to an empty string", provider)
+		provider = ""
+	}
+
+	prURL := getEnv("INFRACOST_VCS_PULL_REQUEST_URL")
+	prID := getEnv("INFRACOST_VCS_PULL_REQUEST_ID")
+	if prURL != "" && prID == "" {
+		prID = getLastURLPart(prURL)
+	}
+
+	return &PullRequest{
+		ID:           prID,
+		VCSProvider:  provider,
+		Title:        getEnv("INFRACOST_VCS_PULL_REQUEST_TITLE"),
+		Author:       getEnv("INFRACOST_VCS_PULL_REQUEST_AUTHOR"),
+		SourceBranch: getEnv("INFRACOST_VCS_BRANCH"),
+		BaseBranch:   getEnv("INFRACOST_VCS_BASE_BRANCH"),
+		URL:          prURL,
+	}
+}
+
+func getLastURLPart(url string) string {
+	pieces := strings.Split(url, "/")
+	if len(pieces) == 0 {
+		return url
+	}
+
+	return pieces[len(pieces)-1]
+}
+
+func keysSet(keys ...string) bool {
+	for _, key := range keys {
+		if getEnv(key) != "" {
+			return true
+		}
+	}
+
+	return false
+}
+
+func buildDefaultCommit() Commit {
+	return Commit{
+		SHA:         getEnv("INFRACOST_VCS_COMMIT_SHA"),
+		AuthorName:  getEnv("INFRACOST_VCS_COMMIT_AUTHOR_NAME"),
+		AuthorEmail: getEnv("INFRACOST_VCS_COMMIT_AUTHOR_EMAIL"),
+		Time:        envToTime("INFRACOST_VCS_COMMIT_TIMESTAMP"),
+		Message:     getEnv("INFRACOST_VCS_COMMIT_MESSAGE"),
+	}
+}
+
+func envToTime(key string) time.Time {
+	env := getEnv(key)
+	if env == "" {
+		return time.Time{}
+	}
+
+	i, err := strconv.ParseInt(env, 10, 64)
+	if err != nil {
+		logging.Logger.WithError(err).Debugf("could not parse 'INFRACOST_COMMIT_TIMESTAMP' value '%s' as int64 timestamp", env)
+		return time.Time{}
+	}
+
+	t := time.Unix(i, 0)
+	// if the year is below these values then the date is considered invalid and will throw a
+	// json marshall error. In this situation we just return a zero time.
+	if y := t.Year(); y < 0 || y >= 10000 {
+		return time.Time{}
+	}
+
+	return t.UTC()
+}
+
 type keyMutex struct {
 	mutexes sync.Map // Zero value is empty and ready for use
 }
@@ -80,6 +242,7 @@ func (m *keyMutex) Lock(key string) func() {
 type metadataFetcher struct {
 	mu     *keyMutex
 	client *http.Client
+	test   *bool
 }
 
 func newMetadataFetcher() *metadataFetcher {
@@ -89,6 +252,14 @@ func newMetadataFetcher() *metadataFetcher {
 	}
 }
 
+func (f *metadataFetcher) isTest() bool {
+	if f.test != nil {
+		return *f.test
+	}
+
+	return getEnv("INFRACOST_ENV") == "test" || strings.HasSuffix(os.Args[0], ".test")
+}
+
 // Get fetches VCS metadata for the given environment.
 // It takes a path argument which should point to the filesystem directory for that should
 // be used as the VCS project. This is normally the path to the `.git` directory. If no `.git`
@@ -96,14 +267,24 @@ func newMetadataFetcher() *metadataFetcher {
 // Get also supplements base VCS metadata with CI specific data if it can be found.
 //
 // When Get encounters an error fetching metadata it will return a default that contains basic Metadata information.
-func (f *metadataFetcher) Get(path string) (Metadata, error) {
-	if isTest() {
+func (f *metadataFetcher) Get(path string) (m Metadata, err error) {
+	defer func() {
+		if f.isTest() {
+			return
+		}
+
+		// let's now merge any user provide metadata from environment variables.
+		// User provided values will always override the parsed metadata.
+		m = mergeEnvProvidedMetadata(m)
+	}()
+
+	if f.isTest() {
 		logging.Logger.Debug("returning stub metadata as Infracost is running in test mode")
 		return StubMetadata, nil
 	}
 
-	_, ok := lookupEnv("GITHUB_ACTIONS")
-	if ok {
+	v, ok := lookupEnv("GITHUB_ACTIONS")
+	if ok && v != "" {
 		logging.Logger.Debug("fetching GitHub action VCS metadata")
 		return f.getGithubMetadata(path)
 	}
@@ -114,7 +295,7 @@ func (f *metadataFetcher) Get(path string) (Metadata, error) {
 		return f.getGitlabMetadata(path)
 	}
 
-	v, ok := lookupEnv("BUILD_REPOSITORY_PROVIDER")
+	v, ok = lookupEnv("BUILD_REPOSITORY_PROVIDER")
 	if ok {
 		if v == "github" {
 			logging.Logger.Debug("fetching GitHub VCS metadata from Azure DevOps pipeline")
@@ -143,12 +324,6 @@ func (f *metadataFetcher) Get(path string) (Metadata, error) {
 		return f.getAtlantisMetadata(path)
 	}
 
-	_, ok = lookupEnv("TFC_RUN_ID")
-	if ok {
-		logging.Logger.Debug("fetching TFC run task metadata")
-		return f.getTFCMetadata(path)
-	}
-
 	logging.Logger.Debug("could not detect a specific CI system, fetching local Git metadata")
 	return f.getLocalGitMetadata(path)
 }
@@ -169,10 +344,6 @@ func lookupEnv(name string) (string, bool) {
 	return strings.TrimSpace(strings.ToLower(v)), ok
 }
 
-func isTest() bool {
-	return os.Getenv("INFRACOST_ENV") == "test" || strings.HasSuffix(os.Args[0], ".test")
-}
-
 func (f *metadataFetcher) getGitlabMetadata(path string) (Metadata, error) {
 	m, err := f.getLocalGitMetadata(path)
 	if err != nil {
@@ -180,28 +351,28 @@ func (f *metadataFetcher) getGitlabMetadata(path string) (Metadata, error) {
 	}
 
 	if m.Branch.Name == "HEAD" {
-		m.Branch.Name = os.Getenv("CI_MERGE_REQUEST_SOURCE_BRANCH_NAME")
+		m.Branch.Name = getEnv("CI_MERGE_REQUEST_SOURCE_BRANCH_NAME")
 	}
 
-	m.Remote = urlStringToRemote(getENVRemoteURL("CI_PROJECT_URL"))
-	m.Pipeline = &Pipeline{ID: os.Getenv("CI_PIPELINE_ID")}
+	m.Remote = urlStringToRemote(getEnv("CI_PROJECT_URL"))
+	m.Pipeline = &Pipeline{ID: getEnv("CI_PIPELINE_ID")}
 	m.PullRequest = &PullRequest{
 		VCSProvider:  "gitlab",
-		ID:           os.Getenv("CI_MERGE_REQUEST_IID"),
-		Title:        os.Getenv("CI_MERGE_REQUEST_TITLE"),
-		Author:       os.Getenv("CI_COMMIT_AUTHOR"),
-		SourceBranch: os.Getenv("CI_MERGE_REQUEST_SOURCE_BRANCH_NAME"),
-		BaseBranch:   os.Getenv("CI_MERGE_REQUEST_TARGET_BRANCH_NAME"),
-		URL:          prURL(os.Getenv("CI_PROJECT_URL") + "/merge_requests/" + os.Getenv("CI_MERGE_REQUEST_IID")),
+		ID:           getEnv("CI_MERGE_REQUEST_IID"),
+		Title:        getEnv("CI_MERGE_REQUEST_TITLE"),
+		Author:       getEnv("CI_COMMIT_AUTHOR"),
+		SourceBranch: getEnv("CI_MERGE_REQUEST_SOURCE_BRANCH_NAME"),
+		BaseBranch:   getEnv("CI_MERGE_REQUEST_TARGET_BRANCH_NAME"),
+		URL:          getEnv("CI_PROJECT_URL") + "/merge_requests/" + getEnv("CI_MERGE_REQUEST_IID"),
 	}
 
 	return m, nil
 }
 
 func (f *metadataFetcher) getGithubMetadata(path string) (Metadata, error) {
-	event, err := os.ReadFile(os.Getenv("GITHUB_EVENT_PATH"))
+	event, err := os.ReadFile(getEnv("GITHUB_EVENT_PATH"))
 	if err != nil {
-		return defaultMetadata, fmt.Errorf("could not read the GitHub event file %w", err)
+		return Metadata{}, fmt.Errorf("could not read the GitHub event file %w", err)
 	}
 
 	m, err := f.getLocalGitMetadata(path)
@@ -216,24 +387,24 @@ func (f *metadataFetcher) getGithubMetadata(path string) (Metadata, error) {
 
 		r, err := git.PlainOpenWithOptions(path, &git.PlainOpenOptions{DetectDotGit: true})
 		if err != nil {
-			return defaultMetadata, fmt.Errorf("could not open git directory to fetch metadata %w", err)
+			return Metadata{}, fmt.Errorf("could not open git directory to fetch metadata %w", err)
 		}
 
 		cnf, err := r.Config()
 		if err != nil {
-			return defaultMetadata, fmt.Errorf("error opening the .git/config folder in github %w", err)
+			return Metadata{}, fmt.Errorf("error opening the .git/config folder in github %w", err)
 		}
 
 		auth := cnf.Raw.Section("http").Subsection("https://github.com/").Options.Get("extraheader")
 		val := strings.TrimSpace(strings.ReplaceAll(auth, "AUTHORIZATION: basic", ""))
 		b, err := base64.URLEncoding.DecodeString(val)
 		if err != nil {
-			return defaultMetadata, fmt.Errorf("GitHub basic auth credentials were malformed, could not decode %w", err)
+			return Metadata{}, fmt.Errorf("GitHub basic auth credentials were malformed, could not decode %w", err)
 		}
 
 		pieces := strings.Split(string(b), ":")
 		if len(pieces) != 2 {
-			return defaultMetadata, fmt.Errorf("GitHub basic auth credentials were malformed, invalid auth components %+v", pieces)
+			return Metadata{}, fmt.Errorf("GitHub basic auth credentials were malformed, invalid auth components %+v", pieces)
 		}
 
 		headRef := gjson.GetBytes(event, "pull_request.head.ref").String()
@@ -250,7 +421,7 @@ func (f *metadataFetcher) getGithubMetadata(path string) (Metadata, error) {
 
 			r, err = git.PlainOpen(clonePath)
 			if err != nil {
-				return defaultMetadata, fmt.Errorf("could not open previously cloned path %w", err)
+				return Metadata{}, fmt.Errorf("could not open previously cloned path %w", err)
 			}
 		} else {
 			logging.Logger.Debugf("cloning auhor commit into '%s'", clonePath)
@@ -267,18 +438,18 @@ func (f *metadataFetcher) getGithubMetadata(path string) (Metadata, error) {
 			unlock()
 
 			if err != nil {
-				return defaultMetadata, fmt.Errorf("could not shallow clone GitHub repo to fetch commit information %w", err)
+				return Metadata{}, fmt.Errorf("could not shallow clone GitHub repo to fetch commit information %w", err)
 			}
 		}
 
 		head, err := r.Head()
 		if err != nil {
-			return defaultMetadata, fmt.Errorf("could not determine head from cloned GitHub branch %w", err)
+			return Metadata{}, fmt.Errorf("could not determine head from cloned GitHub branch %w", err)
 		}
 
 		commit, err := r.CommitObject(head.Hash())
 		if err != nil {
-			return defaultMetadata, fmt.Errorf("could not read head commit from cloned GitHub repo %w", err)
+			return Metadata{}, fmt.Errorf("could not read head commit from cloned GitHub repo %w", err)
 		}
 
 		m.Commit = commitToMetadata(commit)
@@ -286,12 +457,9 @@ func (f *metadataFetcher) getGithubMetadata(path string) (Metadata, error) {
 	}
 
 	remote := gjson.GetBytes(event, "repository.html_url").String()
-	if repoOverrideURL != "" {
-		remote = repoOverrideURL
-	}
 
 	m.Remote = urlStringToRemote(remote)
-	m.Pipeline = &Pipeline{ID: os.Getenv("GITHUB_RUN_ID")}
+	m.Pipeline = &Pipeline{ID: getEnv("GITHUB_RUN_ID")}
 	m.PullRequest = &PullRequest{
 		VCSProvider:  "github",
 		ID:           gjson.GetBytes(event, "pull_request.number").String(),
@@ -299,7 +467,7 @@ func (f *metadataFetcher) getGithubMetadata(path string) (Metadata, error) {
 		Author:       gjson.GetBytes(event, "pull_request.user.login").String(),
 		SourceBranch: gjson.GetBytes(event, "pull_request.head.ref").String(),
 		BaseBranch:   gjson.GetBytes(event, "pull_request.base.ref").String(),
-		URL:          prURL(gjson.GetBytes(event, "pull_request._links.html.href").String()),
+		URL:          gjson.GetBytes(event, "pull_request._links.html.href").String(),
 	}
 
 	return m, nil
@@ -308,17 +476,17 @@ func (f *metadataFetcher) getGithubMetadata(path string) (Metadata, error) {
 func (f *metadataFetcher) getLocalGitMetadata(path string) (Metadata, error) {
 	r, err := git.PlainOpenWithOptions(path, &git.PlainOpenOptions{DetectDotGit: true})
 	if err != nil {
-		return defaultMetadata, fmt.Errorf("could not open git directory to fetch metadata %w", err)
+		return Metadata{}, fmt.Errorf("could not open git directory to fetch metadata %w", err)
 	}
 	head, err := r.Head()
 	if err != nil {
-		return defaultMetadata, fmt.Errorf("could not determine head from local git directory %w", err)
+		return Metadata{}, fmt.Errorf("could not determine head from local git directory %w", err)
 	}
 
 	branch := head.Name().Short()
 	commit, err := r.CommitObject(head.Hash())
 	if err != nil {
-		return defaultMetadata, fmt.Errorf("could not read head commit %w", err)
+		return Metadata{}, fmt.Errorf("could not read head commit %w", err)
 	}
 
 	var remote string
@@ -334,10 +502,6 @@ func (f *metadataFetcher) getLocalGitMetadata(path string) (Metadata, error) {
 		}
 	}
 
-	if remote == "" {
-		remote = repoOverrideURL
-	}
-
 	return Metadata{
 		Remote: urlStringToRemote(remote),
 		Branch: Branch{Name: branch},
@@ -360,17 +524,17 @@ func (f *metadataFetcher) getAzureReposMetadata(path string) (Metadata, error) {
 
 	res := f.getAzureReposPRInfo()
 
-	m.Remote = urlStringToRemote(getENVRemoteURL("BUILD_REPOSITORY_URI"))
-	m.Pipeline = &Pipeline{ID: os.Getenv("BUILD_BUILDID")}
-	pullID := os.Getenv("SYSTEM_PULLREQUEST_PULLREQUESTID")
+	m.Remote = urlStringToRemote(os.Getenv("BUILD_REPOSITORY_URI"))
+	m.Pipeline = &Pipeline{ID: getEnv("BUILD_BUILDID")}
+	pullID := getEnv("SYSTEM_PULLREQUEST_PULLREQUESTID")
 	m.PullRequest = &PullRequest{
 		ID:           pullID,
 		VCSProvider:  "azure_devops_tfsgit",
 		Title:        res.Title,
 		Author:       res.CreatedBy.UniqueName,
-		SourceBranch: strings.TrimLeft(os.Getenv("SYSTEM_PULLREQUEST_SOURCEBRANCH"), "refs/heads/"),
-		BaseBranch:   strings.TrimLeft(os.Getenv("SYSTEM_PULLREQUEST_TARGETBRANCH"), "refs/heads/"),
-		URL:          prURL(fmt.Sprintf("%s/pullrequest/%s", os.Getenv("SYSTEM_PULLREQUEST_SOURCEREPOSITORYURI"), pullID)),
+		SourceBranch: strings.TrimLeft(getEnv("SYSTEM_PULLREQUEST_SOURCEBRANCH"), "refs/heads/"),
+		BaseBranch:   strings.TrimLeft(getEnv("SYSTEM_PULLREQUEST_TARGETBRANCH"), "refs/heads/"),
+		URL:          fmt.Sprintf("%s/pullrequest/%s", getEnv("SYSTEM_PULLREQUEST_SOURCEREPOSITORYURI"), pullID),
 	}
 	return m, nil
 }
@@ -414,13 +578,13 @@ type azurePullRequestResponse struct {
 // an env var on the job step.
 func (f *metadataFetcher) getAzureReposPRInfo() azurePullRequestResponse {
 	var out azurePullRequestResponse
-	systemAccessToken := strings.TrimSpace(os.Getenv("SYSTEM_ACCESSTOKEN"))
+	systemAccessToken := strings.TrimSpace(getEnv("SYSTEM_ACCESSTOKEN"))
 	if systemAccessToken == "" {
 		logging.Logger.Debug("skipping fetching pr title and author, the required pipeline variable System.AccessToken was not provided as an env var named SYSTEM_ACCESSTOKEN")
 		return out
 	}
 
-	apiURL := fmt.Sprintf("%s_apis/git/repositories/%s/pullRequests/%s", os.Getenv("SYSTEM_COLLECTIONURI"), os.Getenv("BUILD_REPOSITORY_ID"), os.Getenv("SYSTEM_PULLREQUEST_PULLREQUESTID"))
+	apiURL := fmt.Sprintf("%s_apis/git/repositories/%s/pullRequests/%s", getEnv("SYSTEM_COLLECTIONURI"), getEnv("BUILD_REPOSITORY_ID"), getEnv("SYSTEM_PULLREQUEST_PULLREQUESTID"))
 	req, _ := http.NewRequest(http.MethodGet, apiURL, nil)
 	req.SetBasicAuth("azdo", systemAccessToken)
 
@@ -460,15 +624,15 @@ func (f *metadataFetcher) getAzureReposGithubMetadata(path string) (Metadata, er
 		}
 	}
 
-	m.Remote = urlStringToRemote(getENVRemoteURL("BUILD_REPOSITORY_URI"))
-	m.Pipeline = &Pipeline{ID: os.Getenv("BUILD_BUILDID")}
-	pullNumber := os.Getenv("SYSTEM_PULLREQUEST_PULLREQUESTNUMBER")
+	m.Remote = urlStringToRemote(os.Getenv("BUILD_REPOSITORY_URI"))
+	m.Pipeline = &Pipeline{ID: getEnv("BUILD_BUILDID")}
+	pullNumber := getEnv("SYSTEM_PULLREQUEST_PULLREQUESTNUMBER")
 	m.PullRequest = &PullRequest{
 		ID:           pullNumber,
 		VCSProvider:  "azure_devops_github",
-		SourceBranch: strings.TrimLeft(os.Getenv("SYSTEM_PULLREQUEST_SOURCEBRANCH"), "refs/heads/"),
-		BaseBranch:   strings.TrimLeft(os.Getenv("SYSTEM_PULLREQUEST_TARGETBRANCH"), "refs/heads/"),
-		URL:          prURL(fmt.Sprintf("%s/pulls/%s", os.Getenv("SYSTEM_PULLREQUEST_SOURCEREPOSITORYURI"), pullNumber)),
+		SourceBranch: strings.TrimLeft(getEnv("SYSTEM_PULLREQUEST_SOURCEBRANCH"), "refs/heads/"),
+		BaseBranch:   strings.TrimLeft(getEnv("SYSTEM_PULLREQUEST_TARGETBRANCH"), "refs/heads/"),
+		URL:          fmt.Sprintf("%s/pulls/%s", getEnv("SYSTEM_PULLREQUEST_SOURCEREPOSITORYURI"), pullNumber),
 
 		// We are unable to fetch pull request title and author for repositories using the GitHub <> Azure DevOps
 		// setup. The relevant information is not provided in the pipeline, and there is no GitHub access token
@@ -485,7 +649,7 @@ func (f *metadataFetcher) getAzureReposGithubMetadata(path string) (Metadata, er
 // in the original Commit of Metadata m. Otherwise, transformAzureDevOpsMergeCommit returns the first commit
 // on a git log call that doesn't appear to be a Merge commit.
 func (f *metadataFetcher) transformAzureDevOpsMergeCommit(path string, m *Metadata) error {
-	m.Branch.Name = strings.TrimLeft(os.Getenv("SYSTEM_PULLREQUEST_SOURCEBRANCH"), "refs/heads/")
+	m.Branch.Name = strings.TrimLeft(getEnv("SYSTEM_PULLREQUEST_SOURCEBRANCH"), "refs/heads/")
 
 	matches := mergeCommitRegxp.FindStringSubmatch(m.Commit.Message)
 	if len(matches) <= 1 {
@@ -558,14 +722,14 @@ func (f *metadataFetcher) getBitbucketMetadata(path string) (Metadata, error) {
 		return m, fmt.Errorf("BitBucket metadata error, could not fetch initial metadata from local git %w", err)
 	}
 
-	m.Remote = urlStringToRemote(os.Getenv("BITBUCKET_GIT_HTTP_ORIGIN"))
-	m.Pipeline = &Pipeline{ID: os.Getenv("BITBUCKET_BUILD_NUMBER")}
+	m.Remote = urlStringToRemote(getEnv("BITBUCKET_GIT_HTTP_ORIGIN"))
+	m.Pipeline = &Pipeline{ID: getEnv("BITBUCKET_BUILD_NUMBER")}
 	m.PullRequest = &PullRequest{
 		VCSProvider:  "bitbucket",
-		ID:           os.Getenv("BITBUCKET_PR_ID"),
-		SourceBranch: os.Getenv("BITBUCKET_BRANCH"),
-		BaseBranch:   os.Getenv("BITBUCKET_PR_DESTINATION_BRANCH"),
-		URL:          prURL(fmt.Sprintf("%s/pull-requests/%s", os.Getenv("BITBUCKET_GIT_HTTP_ORIGIN"), os.Getenv("BITBUCKET_PR_ID"))),
+		ID:           getEnv("BITBUCKET_PR_ID"),
+		SourceBranch: getEnv("BITBUCKET_BRANCH"),
+		BaseBranch:   getEnv("BITBUCKET_PR_DESTINATION_BRANCH"),
+		URL:          fmt.Sprintf("%s/pull-requests/%s", getEnv("BITBUCKET_GIT_HTTP_ORIGIN"), getEnv("BITBUCKET_PR_ID")),
 
 		// we're unable to fetch these without calling the Bitbucket API endpoint:
 		// https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/
@@ -584,13 +748,13 @@ func (f *metadataFetcher) getCircleCIMetadata(path string) (Metadata, error) {
 		return m, fmt.Errorf("circle CI metadata error, could not fetch initial metadata from local git %w", err)
 	}
 
-	m.Remote = urlStringToRemote(getENVRemoteURL("CIRCLE_REPOSITORY_URL"))
-	m.Pipeline = &Pipeline{ID: os.Getenv("CIRCLE_WORKFLOW_ID")}
+	m.Remote = urlStringToRemote(getEnv("CIRCLE_REPOSITORY_URL"))
+	m.Pipeline = &Pipeline{ID: getEnv("CIRCLE_WORKFLOW_ID")}
 	m.PullRequest = &PullRequest{
-		VCSProvider:  "circleci",
-		ID:           os.Getenv("CIRCLE_PR_NUMBER"),
-		SourceBranch: os.Getenv("CIRCLE_BRANCH"),
-		URL:          prURL(os.Getenv("CIRCLE_PULL_REQUEST")),
+		VCSProvider:  vcsProviderFromHost(m.Remote.Host),
+		ID:           getEnv("CIRCLE_PR_NUMBER"),
+		SourceBranch: getEnv("CIRCLE_BRANCH"),
+		URL:          getEnv("CIRCLE_PULL_REQUEST"),
 
 		// we're unable to fetch these without calling the GitHub, Bitbucket or Gitlab API respectively.
 		// Calling the API requires authentication with variables that we don't have access to in the pipeline.
@@ -613,11 +777,10 @@ func (f *metadataFetcher) getAtlantisMetadata(path string) (Metadata, error) {
 	m.Pipeline = &Pipeline{ID: ""}
 
 	m.PullRequest = &PullRequest{
-		VCSProvider:  "atlantis",
-		ID:           os.Getenv("PULL_NUM"),
-		Author:       os.Getenv("PULL_AUTHOR"),
-		SourceBranch: os.Getenv("HEAD_BRANCH_NAME"),
-		BaseBranch:   os.Getenv("BASE_BRANCH_NAME"),
+		ID:           getEnv("PULL_NUM"),
+		Author:       getEnv("PULL_AUTHOR"),
+		SourceBranch: getEnv("HEAD_BRANCH_NAME"),
+		BaseBranch:   getEnv("BASE_BRANCH_NAME"),
 		// Atlantis doesn't provide any indication of which VCS system triggers a build.
 		// So we build the URL using the remote that the local git config points to.
 		URL: getAtlantisPullRequestURL(m.Remote),
@@ -630,56 +793,6 @@ func (f *metadataFetcher) getAtlantisMetadata(path string) (Metadata, error) {
 	return m, nil
 }
 
-// getTFCMetadata returns Metadata built from a TFC request: https://www.terraform.io/cloud-docs/api-docs/run-tasks/run-tasks-integration#request-body
-// We cannot rely on any local git information we run this process in the Infracost Cloud. All OS variables are populated
-// by the Infracost Cloud run task worker, which passes them as environment flags when running the Infracost CLI.
-func (f *metadataFetcher) getTFCMetadata(path string) (Metadata, error) {
-	remote := urlStringToRemote(repoOverrideURL)
-
-	runCreatedAt := os.Getenv("INFRACOST_VCS_COMMIT_CREATED_AT")
-	parsedCreatedAt, err := time.Parse(time.RFC3339, runCreatedAt)
-	if err != nil {
-		logging.Logger.WithError(err).Debugf("could not parse TFC run created time '%s'", runCreatedAt)
-	}
-
-	// pullURL is only populated if the run task is triggered by a VCS webhook event. If the run task has been
-	// triggered by a manual build in Terraform Cloud then TFC_PULL_URL will be blank. This includes builds that
-	// have been originally triggered by a VCS webhook event and then rerun by a user.
-	pullURL := os.Getenv("INFRACOST_VCS_PULL_REQUEST_URL")
-	return Metadata{
-		Remote: remote,
-		Branch: Branch{
-			Name: os.Getenv("INFRACOST_VCS_SOURCE_BRANCH"),
-		},
-		Commit: Commit{
-			SHA:  getLastURLPart(os.Getenv("INFRACOST_VCS_COMMIT_URL")),
-			Time: parsedCreatedAt,
-			// we use the TFC_RUN_MESSAGE as the commit message even though this is the PR title.
-			// This is consistent with what TFC show, i.e. a commit hash and then a PR title.
-			Message: os.Getenv("INFRACOST_VCS_PULL_REQUEST_TITLE"),
-
-			// TFC does not provide us an information on the original VCS author. The only referenced
-			// users are TFC users if the run has been triggered by the UI. We leave these fields blank in
-			// order to avoid confusion.
-			AuthorName:  "",
-			AuthorEmail: "",
-		},
-		PullRequest: &PullRequest{
-			ID:           getLastURLPart(pullURL),
-			VCSProvider:  vcsProviderFromHost(remote.Host),
-			SourceBranch: os.Getenv("INFRACOST_VCS_SOURCE_BRANCH"),
-			URL:          pullURL,
-			Title:        os.Getenv("INFRACOST_VCS_PULL_REQUEST_TITLE"),
-
-			// TFC does not provide us information on the following fields in the event data that's sent
-			// through from the run task.
-			Author:     "",
-			BaseBranch: "",
-		},
-		Pipeline: &Pipeline{ID: os.Getenv("TFC_RUN_ID")},
-	}, nil
-}
-
 func vcsProviderFromHost(host string) string {
 	pieces := strings.Split(host, ".")
 	if len(pieces) == 2 {
@@ -693,24 +806,10 @@ func vcsProviderFromHost(host string) string {
 	return host
 }
 
-func getLastURLPart(urlString string) string {
-	pieces := strings.Split(urlString, "/")
-
-	if len(pieces) == 0 {
-		return urlString
-	}
-
-	return pieces[len(pieces)-1]
-}
-
 func getAtlantisPullRequestURL(remote Remote) string {
-	if prOverrideURL != "" {
-		return prOverrideURL
-	}
-
-	owner := os.Getenv("BASE_REPO_OWNER")
-	project := os.Getenv("BASE_REPO_NAME")
-	pullNumber := os.Getenv("PULL_NUM")
+	owner := getEnv("BASE_REPO_OWNER")
+	project := getEnv("BASE_REPO_NAME")
+	pullNumber := getEnv("PULL_NUM")
 
 	if strings.Contains(remote.Host, "github") {
 		return fmt.Sprintf("https://%s/%s/%s/pull/%s", remote.Host, owner, project, pullNumber)
@@ -838,19 +937,3 @@ func urlStringToRemote(remote string) Remote {
 		URL:  fmt.Sprintf("https://%s/%s", host, path),
 	}
 }
-
-func prURL(url string) string {
-	if prOverrideURL != "" {
-		return prOverrideURL
-	}
-
-	return url
-}
-
-func getENVRemoteURL(key string) string {
-	if repoOverrideURL != "" {
-		return repoOverrideURL
-	}
-
-	return os.Getenv(key)
-}
